@@ -1,16 +1,14 @@
 package Catmandu::Store::Datahub;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Catmandu::Sane;
 
 use Moo;
-use Lido::XML;
 use Catmandu::Store::Datahub::Bag;
 use Catmandu::Store::Datahub::OAuth;
 use LWP::UserAgent;
 
-
 with 'Catmandu::Store';
 
 has url           => (is => 'ro', required => 1);
@@ -19,7 +17,6 @@ has client_secret => (is => 'ro', required => 1);
 has username      => (is => 'ro', required => 1);
 has password      => (is => 'ro', required => 1);
 
-has lido         => (is => 'lazy');
 has client       => (is => 'lazy');
 has access_token => (
     is      => 'lazy',
@@ -30,11 +27,6 @@ has access_token => (
 ##
 # TODO: error reporting 'n stuff
 
-sub _build_lido {
-    my $self = shift;
-    return Lido::XML->new();
-}
-
 sub _build_client {
     my $self = shift;
     return LWP::UserAgent->new();
@@ -57,7 +49,6 @@ sub generate_token {
     return $oauth->token();
 }
 
-
 1;
 
 =head1 NAME
